@@ -6,7 +6,7 @@ Kafka::Connection - Object interface to connect to a kafka cluster.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::Connection> version 1.001011 .
+This documentation refers to C<Kafka::Connection> version 1.001012 .
 
 =cut
 
@@ -20,7 +20,7 @@ use warnings;
 
 our $DEBUG = 0;
 
-our $VERSION = '1.001011';
+our $VERSION = '1.001012';
 
 use Exporter qw(
     import
@@ -366,6 +366,8 @@ In some circumstances (leader is temporarily unavailable, outdated metadata, etc
 This property specifies the maximum number of attempts to send a message.
 The C<$attempts> should be an integer number.
 
+Do not use C<$Kafka::SEND_MAX_ATTEMPTS> in C<Kafka::Producer-<gt>send> request to prevent duplicates.
+
 =item C<RECEIVE_MAX_ATTEMPTS =E<gt> $attempts>
 
 Optional, int32 signed integer, default = C<$Kafka::RECEIVE_MAX_ATTEMPTS> .
@@ -726,7 +728,7 @@ sub receive_response_to_request {
             Data::Dumper->Dump( [ $request ], [ 'request' ] )
         ) if $self->debug_level;
 
-    my $attempts = $self->{SEND_MAX_ATTEMPTS};
+    my $attempts = $api_key == $APIKEY_PRODUCE ? 1 : $self->{SEND_MAX_ATTEMPTS};
     my ( $ErrorCode, $partition_data, $server );
     ATTEMPTS:
     while ( $attempts-- ) {
